@@ -36,8 +36,7 @@ module.exports = __toCommonJS(origin_request_edge_lambda_exports);
 var path = __toESM(require("path"));
 async function handler(event) {
   const request = event.Records[0].cf.request;
-  if (!path.extname(request.uri))
-    request.uri = "/index.html";
+  if (!path.extname(request.uri)) request.uri = "/index.html";
   return request;
 }
 // Annotate the CommonJS export names for ESM import in node:
