@@ -24,11 +24,12 @@ __export(shortener_lambda_exports, {
 });
 module.exports = __toCommonJS(shortener_lambda_exports);
 var import_url = require("url");
-var import_aws_sdk = require("aws-sdk");
+var import_client_dynamodb = require("@aws-sdk/client-dynamodb");
+var import_client_s3 = require("@aws-sdk/client-s3");
+var import_lib_dynamodb = require("@aws-sdk/lib-dynamodb");
 function base62Encode(int) {
   const characterSet = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
-  if (int === 0)
-    return "0";
+  if (int === 0) return "0";
   let s = "";
   while (int > 0) {
     s = characterSet[int % 62] + s;
@@ -54,10 +55,10 @@ function isUrlValid(url) {
     return false;
   }
 }
-var documentClient = new import_aws_sdk.DynamoDB.DocumentClient({ apiVersion: "2012-08-10" });
-var s3 = new import_aws_sdk.S3({ apiVersion: "2006-03-01" });
+var dynamoDBClient = new import_client_dynamodb.DynamoDBClient({});
+var documentClient = import_lib_dynamodb.DynamoDBDocumentClient.from(dynamoDBClient);
+var s3Client = new import_client_s3.S3Client({});
 async function handler(event) {
-  var _a;
   console.log("Event: %j", event);
   const response = {
     statusCode: 201,
@@ -72,26 +73,26 @@ async function handler(event) {
         statusCode: 400
       };
     }
-    const update = await documentClient.update({
+    const update = await documentClient.send(new import_lib_dynamodb.UpdateCommand({
       TableName: getEnv("TABLE_NAME"),
       Key: { key: "counter" },
       UpdateExpression: "ADD #value :incr",
       ExpressionAttributeNames: { "#value": "value" },
       ExpressionAttributeValues: { ":incr": 1 },
       ReturnValues: "UPDATED_NEW"
-    }).promise();
-    const value = (_a = update.Attributes) == null ? void 0 : _a.value;
+    }));
+    const value = update.Attributes?.value;
     if (!value) {
       throw new Error("Cannot get next counter value");
     }
     const key = base62Encode(value);
     console.log("Key: %j", key);
-    const putObject = await s3.putObject({
+    const putObject = await s3Client.send(new import_client_s3.PutObjectCommand({
       Bucket: getEnv("BUCKET_NAME"),
       Key: key,
       ContentType: "application/json",
       Body: JSON.stringify({ url: body.url })
-    }).promise();
+    }));
     console.log("Put object: %j", putObject);
     return {
       ...response,
